<?php
/**
 * This file handles all 'active' parts (adding, removing rows in the DB etc.)
 *
 * $Id: actions.php 211 2007-07-20 11:28:02Z rbott $
 *
 * @package ZoneAdmin
 * @author Rudolph Bott
 * @version 0.1
 * @copyright Rudolph Bott
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 */

// vim:tabstop=2:expandtab:shiftwidth=2:filetype=php:syntax:ruler:

require('includes/defaults.php');
require('includes/config.php');

if(!empty($_SERVER['REMOTE_USER'])) $cfg['user'] = $_SERVER['REMOTE_USER'];

if(isset($_POST['action'])) $action = $_POST['action'];
else if(isset($_GET['action'])) $action = $_GET['action'];
else $action = '';

$_params = '';
$_append_errors = '';


switch($action) {
  case 'addrec':

    if(valid_record($_POST['name'],$_POST['type'],$_POST['content'],$_POST['prio'],$_POST['ttl'])) {
      $id = add_domain_record($_POST['zone'],$_POST['name'],$_POST['type'],$_POST['content'],$_POST['prio'],$_POST['ttl']);

      if($id > 0 && !empty($_POST['comment'])) add_comment($_POST['zone'],$id,$cfg['user'],$_POST['comment']);

      if($_POST['AddAnother'] == 'true') {
        $_params = '?section=addrec&addanother=true&zone='.$_POST['zone'];
      }
      else {
        if(isset($_POST['raise_serial'])) {
          raise_serial($_POST['zone']);
        }
        $_params = '?section=showzone&zone='.$_POST['zone'];
      }
    }
    else {
      add_error(ERR_INVAL_RECORD,__FUNCTION__);
      $_params = '?section=addrec&zone=' . $_POST['zone']; //. '&name=' . urlencode($_POST['name']) . '&type=' . urlencode($_POST['type']) . '&content=' . urlecnde($_POST['content']) . '&prio=' . urlencode($_POST['prio']);
    }
  break;
  case 'updaterec':
    update_domain_record($_POST['zone'],$_POST['record'],$_POST['name'],$_POST['type'],$_POST['content'],$_POST['prio'],$_POST['ttl']);
    
    //wir sparen uns mal ein raise_serial(), wenn hier jemand grad im SOA record rumpfuscht
    if($_POST['type'] != 'SOA' && isset($_POST['raise_serial'])) {
      raise_serial($_POST['zone']);
    }

    if(comment_exists($_POST['zone'],$_POST['record'])) {
      if(!empty($_POST['comment'])) {
        update_comment($_POST['zone'],$_POST['record'],$cfg['user'],$_POST['comment']);
      }
      else {
        del_comment($_POST['zone'],$_POST['record']);
      }
    }
    else {
      add_comment($_POST['zone'],$_POST['record'],$cfg['user'],$_POST['comment']);
    }

    $_params = '?section=showzone&zone='.$_POST['zone'];

  break;
  case 'delrec':

    $saveorigin = $cfg['striporigin'];
    $cfg['striporigin'] = false;
    $host = get_domain_record($_GET['record']);
    $cfg['striporigin'] = $saveorigin;

    if($host['type'] == 'A' && has_references($host['name'])) {
      Header('Location: '.$cfg['domain'].$cfg['reldir'].'index.php?section=showzone&zone='.$_GET['zone'].'&record='.$_GET['record'].'&ref_error=true');
      exit;
    }

    del_domain_record($_GET['record'],$_GET['zone']);

    raise_serial($_GET['zone']);

    $_params = '?section=showzone&zone='.$_GET['zone'];
  break;
  case 'updatesoa':

    if(!empty($_POST['master']) && !empty($_POST['contact']) && !empty($_POST['serial']) && !empty($_POST['refresh']) && !empty($_POST['retry']) && !empty($_POST['expire']) && !empty($_POST['ttl']) && !empty($_POST['zone'])) {
      $soa = get_domain_records_by_type($_POST['zone'],'SOA');
      if(count($soa) == 1) {
        $soastring = $_POST['master'].' '.$_POST['contact'].' '.$_POST['serial'].' '.$_POST['refresh'].' '.$_POST['retry'].' '.$_POST['expire'].' '.$_POST['ttl'];
        $update = update_domain_record($_POST['zone'],$soa[0]["id"],'','SOA',$soastring,0,$_POST['ttl']);
      }
      $_params = '?section=showzone&zone='.$_POST['zone'];
    }
    else {
      $_params = '?section=editsoa&zone='.$_POST['zone'];
    }

  break;
  case 'addtpl':
    $new_tpl = add_template($_POST['name']);
    $_params = '?section=addtplrec&template='.$new_tpl;
  break;
  case 'deltpl':
    del_template($_GET['template']);
    $_params = '?section=templates';
  break;
  case 'addtplrec':
    add_template_record($_POST['template'],$_POST['name'],$_POST['type'],$_POST['content'],$_POST['prio'],$_POST['ttl']);

    if($_POST['AddAnother'] == 'true') {
      $_params = '?section=addtplrec&addanother=true&template='.$_POST['template'];
    }                                                                                                        
    else {                                                                                                   
      $_params = '?section=showtpl&template='.$_POST['template'];
    }
  break;
  case 'updatetplrec':
    update_template_record($_POST['template'],$_POST['record'],$_POST['name'],$_POST['type'],$_POST['content'],$_POST['prio'],$_POST['ttl']);
    $_params = '?section=showtpl&template='.$_POST['template'];

  break;
  case 'deltplrec':
    del_template_record($_GET['record'],$_GET['template']);
    $_params = '?section=showtpl&template='.$_GET['template'];
  break;
  case 'addzone':
    if(!domain_exists($_POST['domain'])) {
      $domain_id = add_domain($_POST['domain'],$_POST['template']);
      $_params = '?section=showzone&zone='.$domain_id;
    }
    else {
      add_error(ERR_ZONE_EXISTS);
      $_params = '?section=addzone';
    }
  break;
  case 'delzone':
    if(isset($_GET["disabled"])) {
      del_domain($_GET['zone'],true);
    }
    else {
      del_domain($_GET['zone']);
    }
  break;
  case 'disablezone':
    disable_domain($_GET['zone']);
    $_params = '?section=disabledzones';
  break;
  case 'enablezone':
    $domain = get_domain_from_id($_GET['zone'],true);
    enable_domain($_GET['zone']);
    $domain_id = get_id_from_domain($domain);
    $_params = '?section=showzone&zone=' . $domain_id;
  break;
  case 'zonecomment':
    //gibt es den kommentar schon?
    if(comment_exists($_POST['zone'],0)) {
      //wenn ja, hat ueberhaupt jemand was eingegeben?
      if(!empty($_POST['comment'])) {
        //ja, also bestehenden kommentar updaten
        update_comment($_POST['zone'],0,$cfg['user'],$_POST['comment']);
      }
      else {
        //nichts eingegeben, also bestehenden kommentar loeschen
        del_comment($_POST['zone'],0);
      }
    }
    else {
      //kommentar gibts noch nicht, also bitte anlegen
      add_comment($_POST['zone'],0,$cfg['user'],$_POST['comment']);
    }
    $_params = '?section=showzone&zone='.$_POST['zone'];
  break;
  case 'delcomment';
    del_comment($_POST['id']);
    $_params = '?section=showzone&zone='.$_POST['zone'];
  break;
}

//if any error(s) occured, find them and join them into one large 'GETtable' string to
//pass it over to index.php

if(count($_errors) > 0) {
  $strings = array();
  foreach($_errors AS $error) {
    $strings[] = join('%',$error);
  }
  $string = join('~',$strings);
  $_append_errors = 'errors='.rawurlencode($string);
  if($_params == '') {
    $_append_errors = "?" . $_append_errors;
  }
  else {
    $_append_errors = "&" .  $_append_errors;
  }
}

//Go, Go, Go!
Header('Location: '.$cfg['domain'].$cfg['reldir'].'index.php'.$_params.$_append_errors);
exit;
?>
