<?php

/**
 * Provides error handling routines
 *
 * $Id: functions.errors.php 185 2007-05-10 22:44:39Z rbott $
 *
 * @package ZoneAdmin
 * @author Rudolph Bott
 * @version 0.1
 * @copyright Rudolph Bott
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 */


/**
 * translate error code to human readable message
 *
 * takes an error as parameter and translates it
 * to its corresponding (localized) error message
 * for output
 *
 * @param integer error code
 * @return string localized error message
 * @author Rudolph Bott
 * @copyright Copyright 2007, Rudolph Bott
 * @version 1.0
 */

function translate_error($error) {
  switch($error) {
  case ERR_GENERAL:
    return translate('err_general');
    break;
  case ERR_ZONE_EXISTS:
    return translate('err_zone_exists');
    break;
  case ERR_MISSING_SOA:
    return translate('err_missing_soa');
    break;
  case ERR_INVAL_SOA:
    return translate('err_inval_soa');
    break;
  case ERR_INVAL_SERIAL:
    return translate('err_inval_serial');
    break;
  case ERR_HAS_REFS:
    return translate('err_has_refs');
    break;
  case ERR_INVAL_DOMAIN_ID:
    return translate('err_inval_domain_id');
    break;
  case ERR_INVAL_DOMAIN:
    return translate('err_inval_domain');
    break;
  case ERR_NO_EDIT_SLAVE:
    return translate('err_no_edit_slave');
    break;
  case ERR_INVAL_RECORD:
    return translate('err_inval_record');
    break;
  case ERR_INVAL_NAME:
    return translate('err_inval_name');
    break;
  case ERR_INVAL_CONTENT:
    return translate('err_inval_content');
    break;
  case ERR_INVAL_PRIO:
    return translate('err_inval_prio');
    break;
  case ERR_INVAL_TTL:
    return translate('err_inval_ttl');
    break;
  case ERR_MYSQL_GENERAL:
    return translate('err_mysql_general');
    break;
  case ERR_MYSQL_SYNTAX:
    return translate('err_mysql_syntax');
    break;
  default:
    return 'Undefined Error!';
  }
}

/**
 * adds an error to the error list
 *
 * this function adds an error code to
 * the _errors array
 *
 * @param integer error code
 * @return void
 * @author Rudolph Bott
 */

function add_error($error,$caller = "unknown",$extra = "") {
  global $_errors;

  $newerror = array ('error' => $error, 'function' => $caller, 'extra' => $extra);

  $_errors[] = $newerror;
}


/**
 * returns the last error code
 *
 * this function returns the last
 * error code that has been added 
 * to the _errors array
 *
 * @return integer error code
 * @author Rudolph Bott
 * @version 1.0
 */

function last_error() {
  global $_errors;

  if(count($_errors) > 0) {
    return $_errors[count($_errors)-1];
  }
  else {
    return 0;
  }
}
?>
